# coding=utf8


import sys

sys.path.append('..')

from hupu.hupuapp import start

if __name__ == '__main__':
    # sizex, sizey = get_terminal_size()
    # print('width =', sizex, 'height =', sizey)
    start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午3:58
# @Author  : wudizhangzhi
import datetime
import json
import time
from random import choice

from hupu.api import logger
from hupu.api.base import Base
from hupu.messages.messages import Game

log = logger.getLogger(__name__)


class LiveMinxin(Base):
    def _get_gamesobject_list(self, games_json):
        """
        :param games_json: 
        :return: 
        """
        today = datetime.datetime.today().strftime('%Y%m%d')

        games = games_json['result']['games']
        games_today = [i for i in games if i['day'] == today]
        games_today = games_today[0]
        # rank_url = games_today['rank_url']
        game_datas = games_today['data']

        game_object_list = []
        for _game_data in game_datas:
            gid = _game_data['gid']
            if len(gid) > 6:
                continue
            g = Game(_game_data)
            game_object_list.append(g)
        return game_object_list

    def _getGames(self, gametype=None):
        """
        获取比赛列表
        """
        if gametype:
            assert gametype.lower() in ['nba', 'cba']
        else:
            gametype = 'nba'
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/{}/getGames'.format(self.api_version, gametype),
            params={
                'crt': int(time.time() * 1000),
                'night': 0,
                'channel': 'myapp',
                'client': self.client,
                'time_zone': 'Asia/Shanghai',
                'android_id': self.android_id,
            }
        )

    def getGames(self, gametype=None):
        r = self._getGames(gametype).json()
        log.debug('获取比赛列表: {}'.format(r))
        return self._get_gamesobject_list(r)

    def getPlaybyplay(self, gid):
        """
        获取比赛直播信息
        :param gid: 
        :return: 
        """
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/room/getPlaybyplay'.format(self.api_version),
            params={
                'gid': gid,
                'crt': int(time.time() * 1000),
                'lid': '1',
                'roomid': '-1',
                'tag': 'nba',  # 默认nba
                'night': 0,
                'channel': 'myapp',
                'client': self.client,
                'time_zone': 'Asia/Shanghai',
                'android_id': self.android_id,
                'entrance': '-1',
            },
        )

    def getInit(self):
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/status/init'.format(self.api_version),
            params={
                'dv': '5.7.79',
                'crt': int(time.time() * 1000),
                'tag': 'nba',  # 默认nba
                'night': 0,
                'channel': 'myapp',
                'client': self.client,
                'time_zone': 'Asia/Shanghai',
                'android_id': self.android_id,
            },
        )

    def getIpAdress(self):
        host = port = None

        try:
            r_json = self.getInit().json()
            log.debug('ip地址获取: {}'.format(json.dumps(r_json, indent=2)))
            ip_adress_list = choice(r_json['result']['redirector'])
            log.debug('ip地址使用: {}'.format(ip_adress_list))
            tmp = ip_adress_list.split(':')
            host = tmp[0]
            port = int(tmp[1])
        except:
            pass
        return host, port



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/29 下午8:28
# @Author  : wudizhangzhi
import sys

sys.path.append('..')
# from hupu.hupuapp import HupuApp
from hupu.menus.HupuMenu import HupuMenu


def test():
    # hupuapp = HupuApp()
    menu = HupuMenu(None)

    def choose_game(menu):
        teamranks = menu.hupuapp.getDatas()
        menu.items = teamranks
        menu.subtitle = '球队数据排行:'
        menu.draw()

    menu.register(ord(' '), 'live', choose_game)

    # menu.draw()
    # menu.listen()
    menu.quit()
    print(menu.key_bind_events)


if __name__ == '__main__':
    test()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午11:40
# @Author  : wudizhangzhi

import sys

sys.path.append('..')
from hupu.messages.messages import ScoreBoard, SocketMessage, BaseMessage
from hupu.messages.entries import StringEntry, IntEntry, ListEntry


class Integer:
    def __init__(self, name):
        self.name = name

    def __get__(self, instance, cls):
        if instance is None:
            return self
        else:
            return instance.__dict__[self.name]

    def __set__(self, instance, value):
        if not isinstance(value, int):
            raise TypeError('Expected an int')
        instance.__dict__[self.name] = value

    def __delete__(self, instance):
        del instance.__dict__[self.name]


class Test(BaseMessage):
    test = ListEntry('result.casino_update.desc')


def test_entry():
    # sb = ScoreBoard({'home_tid': 123})
    # print(sb.home_tid)
    # print(type(sb.home_tid))
    # print(type(sb))
    data = {
        "room": "NBA_PLAYBYPLAY_CASINO",
        "pid": 443,
        "result": {},
        "type": "nba",
        "gid": "153749",
        "room_live_type": "1"
    }

    class A(BaseMessage):
        __type__ = 'test'
        room_live_type = IntEntry('room_live_type')
        gid = ''

    a = A(data)
    print(a.__dict__)
    print(a.room_live_type, type(a.room_live_type))
    print(a.gid, type(a.gid))
    a.room_live_type = 12
    # s = SocketMessage(data)
    # print(s.__dict__)
    # print(s.room_live_type, type(s.room_live_type))


def test_listentry():
    data = {"name": "wall", "args": [{"room": "NBA_PLAYBYPLAY_CASINO", "gid": "153733", "status": "2", "result": {
        "casino_update": [
            {"casino_id": 412051, "desc": "470人参与，394人选「能」", "max_bet": 0, "status": {"id": 1, "desc": "竞猜中"},
             "user_count": 470, "user_win_coins": 0},
            {"casino_id": 412050, "desc": "571人参与，469人选「能」", "max_bet": 0, "status": {"id": 1, "desc": "竞猜中"},
             "user_count": 571, "user_win_coins": 0},
            {"casino_id": 412046, "desc": "574人参与，303人选「能」", "max_bet": 0, "status": {"id": 1, "desc": "竞猜中"},
             "user_count": 574, "user_win_coins": 0},
            {"casino_id": 412041, "desc": "1014人参与，678人选「骑士」", "max_bet": 0, "status": {"id": 1, "desc": "竞猜中"},
             "user_count": 1014, "user_win_coins": 0},
            {"casino_id": 412037, "desc": "950人参与，604人选「不会」", "max_bet": 0, "status": {"id": 1, "desc": "竞猜中"},
             "user_count": 950, "user_win_coins": 0}]}, "online": "43万"}]}
    test = Test(data['args'][0])
    print(test.__dict__)
    print(test.test)


if __name__ == '__main__':
    # test_entry()
    test_listentry()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi

import json
import os
import random
import re
import traceback
from hashlib import md5
# TODO
try:
    from html import unescape
except ImportError:
    from HTMLParser import HTMLParser

    unescape = HTMLParser().unescape

from colored import stylize

from hupu.api import logger
from hupu.messages.messages import SocketMessage

log = logger.getLogger(__name__)

HUPU_SALT = 'HUPU_SALT_AKJfoiwer394Jeiow4u309'

TAC_LIST = ['35651900', '35666503', '91054200',
            '35537803', '44831527', '86489400',
            '35084240', '13004008', '35103090',
            '35332802']


def luhn_residue(digits):
    return sum(sum(divmod(int(d) * (1 + i % 2), 10))
               for i, d in enumerate(digits[::-1])) % 10


def get_random_Imei(N=None, filename=None):
    if not N:
        N = 15
    return getImei(N, get_random_tac(filename))


def getImei(N, tac=None):
    '''
    IMEI就是移动设备国际身份码，我们知道正常的手机串码IMEI码是15位数字，
    由TAC（6位，型号核准号码）、FAC（2位，最后装配号）、SNR（6位，厂商自行分配的串号）和SP（1位，校验位）。
    tac数据库: https://www.kaggle.com/sedthh/typeallocationtable/data
    :param N:
    :return:
    '''
    part = ''.join(str(random.randrange(0, 9)) for _ in range(N - 1))
    if tac:
        part = tac + part[len(tac):]
    res = luhn_residue('{}{}'.format(part, 0))
    return '{}{}'.format(part, -res % 10)


def get_random_tac(filename=None):
    if not filename:
        filename = 'tac.csv'
    if not os.path.exists(filename):
        return random.choice(TAC_LIST)
    with open(filename, 'r') as f:
        lines = f.readlines()
        line = random.choice(lines)
        return line.split(',')[0]


def get_android_id():
    # 固定 adb shell settings get secure android_id 随机64位数字的16进制
    result = ''
    for _ in range(64):
        result += random.choice(['0', '1'])
    return hex(int(result, base=2))[2:]


def getSortParam(**kwargs):
    result = ''
    kwargs_sorted = sorted(kwargs)
    for key in kwargs_sorted:
        if len(result) > 0:
            result += '&'
        result += '='.join((key, str(kwargs.get(key))))
    result += HUPU_SALT
    return md5(result.encode('utf8')).hexdigest()


def parse_message(message):
    try:
        message_json = json.loads(message[11:])
        log.debug(json.dumps(message_json, indent=2))
        return SocketMessage(message_json['args'][0])
    except Exception as e:
        log.debug(traceback.format_exc())
        return None


def colored_text(text, *style):
    return stylize(text, *style)


def purge_text(text):
    return unescape(re.sub(r'<[^>]+>|[\n\r\t]+', '', text))


def text_to_list(text, width):
    return [i for i in re.findall(r'.{,%s}' % width, text) if i.strip()]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi
"""Hupu.
    Proudly presented by Hupu JRs.

Usage:
    hupu [-m MODE] [-a APIVERSION] [-d DATATYPE] [-u USERNAME] [-p PASSWORD]
    hupu -h | --help
    hupu -v | --version

Tips:
    Please hit Ctrl-C on the keyborad when you want to interrupt the game live.

Options:
    -u USERNAME --username=USERNAME         Input username.
    -p PASSWORD --password=PASSWORD         Input password.
    -a APIVERSION --apiversion=APIVERSION   Api version.[default: 7.1.15]
    -m MODE --mode=MODE                     Run mode.Available: live news teamranks...[default: live]
    -d DATATYPE --datatype=DATATYPE         Player data type.Available: regular, injury, daily[default:regular]
    -h --help                               Show this help message and exit.
    -v --version                            Show version.
"""
from __future__ import print_function
# python2 curses addstr乱码问题
import locale

locale.setlocale(locale.LC_ALL, '')
import requests
import curses
import colored
import docopt
import traceback

try:
    # 不打印ssl警告
    requests.packages.urllib3.disable_warnings()
except ImportError:
    pass

from hupu.api.live import LiveMinxin
from hupu.api.login import LoginMixin
from hupu.api.news import NewsMixin
from hupu.api.datas import DatasMixin
from hupu.utils import colored_text
from hupu.api import logger
from hupu.menus.HupuMenu import HupuMenu
from hupu.version import version

log = logger.getLogger(__name__)

MODE_LIST = ['live', 'news', 'teamranks', 'playerdata']


class HupuApp(LiveMinxin, NewsMixin, LoginMixin, DatasMixin):
    def run(self):
        # 判断参数, 执行哪一种场景
        # 1.没参数
        # 2.有用户名密码 -- 登录

        # 默认进入比赛文字直播模式
        mode = self._kwargs.get('mode', '') or 'live'
        mode = mode.lower()
        assert mode in MODE_LIST, AttributeError('Expect mode is {}, got {}.'.format(', '.join(MODE_LIST), mode))
        try:
            hupumenu = HupuMenu(self)
            items = []
            if mode == 'live':  # 文字直播模式
                items = self.getGames()

            elif mode == 'news':  # 新闻模式
                items = self.getNews()
                hupumenu.body_title = '新闻:'

            elif mode == 'teamranks':  # 球队数据模式
                items = self.getDatas()
                hupumenu.body_title = '球队数据:'

            elif mode == 'playerdata':  # 球队数据模式
                datatype = self._kwargs.get('datatype')
                if not datatype or datatype not in ['regular', 'injury', 'daily']:
                    datatype = 'regular'
                datatype = datatype.lower()
                items = self.getPlayerDataInGenernal(datatype)
                hupumenu.body_title = '球员数据:'

            if not items:
                raise Exception('没有数据!')
            hupumenu.set_items(items)
            hupumenu.mode = mode

            hupumenu.draw()
            hupumenu.listen()

        except curses.error as e:
            curses.endwin()
            log.error(e)
            print(colored_text('窗口太小, 请调整窗口大小!', colored.fg("red") + colored.attr("bold")))
        except Exception as e:
            log.error(traceback.format_exc())
            if not curses.isendwin():
                curses.endwin()
            print(e)


def start():
    arguments = docopt.docopt(__doc__, version='Hupu {}'.format(version))
    # 处理参数
    arguments = {k.replace('--', ''): v for k, v in arguments.items()}
    hupulive = HupuApp(**arguments)
    hupulive.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi
from __future__ import absolute_import
from __future__ import print_function

import time

import colored
import requests

from hupu.api import logger
from hupu.utils import colored_text, parse_message
from hupu.messages.entries import to_text

log = logger.getLogger(__name__)
log = logger.getLogger('websocket')
import websocket


class HupuLiveWebSocket(object):
    def __init__(self, client, game, host=None, port=None, livetype=None):
        """
        虎扑文字直播websocket的基类
        :param client: 
        :param host: 
        :param port: 
        :param livetype: 文字直播的类型: [NBA, CBA]
        """
        self.client = client
        self.game = game
        self.pid = None
        self.HOST = host or '61.174.11.224'
        self.PORT = port or 3081

        self._connected = False  # 是否连接过

        if not livetype:
            self.livetype = 'NBA'
        else:
            self.livetype = livetype

        self.heart_beat_count = 0
        # self.ws = None

    def get_token(self):
        """
        post /socket.io/1/?client=008796750504411&t=1516672901&type=1&background=false
        response 包含 012tC3NMo1FlJsPhaSdh:50:60:websocket,htmlfile,xhr-polling,jsonp-polling
        :return: str example 012tC3NMo1FlJsPhaSdh
        """
        t = int(time.time())
        url = 'http://{host}:{port}/socket.io/1/?client={client}&t={t}&type=1&background=false'.format(host=self.HOST,
                                                                                                       port=self.PORT,
                                                                                                       client=self.client,
                                                                                                       t=t)
        r = requests.post(url, timeout=10)
        return r.text.split(':50:60')[0]

    @property
    def msg_send_to_get_match(self):
        return '5::/nba_v1:{"args":[{"room":"%s_HOME"}],"name":"join"}' % self.livetype

    def run(self):
        token = self.get_token()
        t = int(time.time())
        ws = websocket.WebSocketApp(
            "ws://{host}:{port}/socket.io/1/websocket/{token}/?client={client}&t={t}&type=1&background=false".format(
                host=self.HOST, port=self.PORT, token=token, client=self.client, t=t
            ),
            on_message=self.on_message,
            on_error=self.on_error,
            on_close=self.on_close,
            on_open=self.on_open,
        )
        log.debug('=== start websocket ===')
        ws.run_forever()

    def send(self, ws, message):
        ws.send(message)
        log.debug('send: {}'.format(message))

    def on_message(self, ws, message):
        """
        收到消息时候的回调
        """
        message = to_text(message)
        log.debug('receive: {}'.format(to_text(message)))
        msg = ''  # 返回的消息
        if message == '1::':
            msg = '2:::'
        elif message == '2::':
            if self._connected:
                msg = '2::'
            else:
                self._connected = True
                msg = '1::/nba_v1'
        elif message in ['1::/nba_v1']:  # 开始获取数据
            msg = self.on_match_message(ws, message)
        else:  # 数据部分
            socket_message = parse_message(message)
            if not socket_message:
                return
            if socket_message.room == 'NBA_HOME':
                pass
            else:
                self.on_live_message(ws, socket_message)
                self.heart_beat(ws)

            if socket_message.room_live_type == -1:  # 比赛结束
                print('----- 直播结束了, 即将退回菜单 -----', end='\n\r')
                time.sleep(3)
                ws.close()

        if msg:
            self.send(ws, msg)

    def on_match_message(self, ws, message):
        """
        返回比赛信息(比赛的gid, 比分, 情况)之后的回调
        例如 发送 '5::/nba_v1:{"args":[{"roomid":-1,"gid":100721,"pid":429,"room":"NBA_PLAYBYPLAY_CASINO"}],"name":"join"}'
        """
        # TODO 不太明白
        return '5::/nba_v1:{"args":[{"roomid":-1,"gid":%s,"pid":%s,"room":"NBA_PLAYBYPLAY_CASINO"}],"name":"join"}' % (
            self.game.gid, self.pid or 617)

    def on_live_message(self, ws, socket_message):
        """
        比赛直播信息
        :param ws: 
        :param message: 
        :return: 
        """
        pass

    def on_error(self, ws, error):
        # print('error: {}'.format(error))
        log.error('=== onerror: {} ==='.format(error))

    def on_close(self, ws):
        print('\n\r')
        print('|文字直播关闭|\n\r')
        log.debug('=== on close ===')

    def on_open(self, ws, *args, **kwargs):
        print('\n\r')
        print('|直播室连接中...|\n\r')
        log.debug('=== on open ===')

    def heart_beat(self, ws):
        """
        每隔5次心跳返回
        """
        self.heart_beat_count += 1
        if self.heart_beat_count > 5:
            self.heart_beat_count = 0
            heart_beat_msg = '2:::'
            self.send(ws, heart_beat_msg)
            log.debug('--- heart beat ---')


class HupuSocket(HupuLiveWebSocket):
    last_time = None  # 上次消息的时间
    last_pid = None  # 上次的pid

    def on_live_message(self, ws, socket_message):
        scoreboard, msgs = socket_message.scoreboard, socket_message.livemessges
        for msg in msgs:
            if not self.last_time or msg.t > self.last_time:
                self.print_live(scoreboard, msg)
                self.last_time = msg.t
        if hasattr(scoreboard, 'pid'):
            self.pid = scoreboard.pid
        return scoreboard, msgs

    def print_live(self, scoreboard, msg):
        """
        打印直播信息
        """
        print("{} \n\r".format(' | '.join((self.colored_scoreboard(scoreboard), str(msg)))))

    def colored_scoreboard(self, scoreboard):
        home_score = scoreboard.home_score
        away_score = scoreboard.away_score
        try:
            if int(home_score) > int(away_score):
                home_score = colored_text(home_score, colored.fg("red") + colored.attr("bold"))
            else:
                away_score = colored_text(away_score, colored.fg("red") + colored.attr("bold"))
        except Exception as e:
            pass
        text = '{home} {home_score}:{away_score} {away}  {process}'.format(
            home_score=home_score,
            away_score=away_score,
            process=scoreboard.process,
            home=self.game.home_name,
            away=self.game.away_name,
        )
        return text


def test_color():
    from messages.messages import ScoreBoard, Game
    game = Game({'gid': 153735, 'home_name': '勇士', 'away_name': '骑士'})

    hlws = HupuSocket(game=game, client='008796750504411', host='61.174.11.224', port=3081)
    sb = ScoreBoard({'home_score': 120, 'away_score': 89})
    # print(hlws.colored_scoreboard(sb))
    hlws.print_live(sb, '主持人: 雷阿伦左侧开球！this is a test!!!')


def test():
    from hupu.messages.messages import Game
    # import sys
    import curses
    #
    def incurses(stdscr):
        stdscr.addstr(0, 0, "Exiting in ")
        stdscr.addstr(2, 0, "Hello World from Curses!")
        for i in range(5, -1, -1):
            stdscr.addstr(0, 11, str(i))
            stdscr.refresh()
            time.sleep(1)
        curses.endwin()

    curses.wrapper(incurses)
    print("After curses")
    # # curses.echo()
    # # curses.reset_shell_mode()
    # # print(sys.stdout)
    # game = Game({'gid': 153735, 'home_name': '勇士', 'away_name': '骑士'})
    # hlws = HupuSocket(game=game, client='008796750504411', host='127.0.0.1', port=5000)
    # hlws.run()
    # #
    # # def get_token():
    # #     return ''
    # #
    # # hlws.get_token = get_token
    # # hlws.run()
    i = 0
    while i < 100:
        print('this is a test. {}'.format(i))
        i += 1
        time.sleep(1)
    #


if __name__ == '__main__':
    # hlws = HupuLiveWebSocket(client='008796750504411', host='61.174.11.224', port=3081)
    # hlws = HupuSocket(gid=153735, client='008796750504411', host='61.174.11.224', port=3081)
    # hlws.run()

    # test_color()
    test()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午3:53
# @Author  : wudizhangzhi


import requests

try:
    requests.packages.urllib3.disable_warnings()
except ImportError:
    pass
from user_agent import generate_user_agent

from hupu.utils import getSortParam, get_android_id, get_random_Imei
from hupu.api import logger

log = logger.getLogger(__name__)

HUPU_API_VERSION = '7.1.15'

MODE_LIST = ['live', 'news']


class SignSession(requests.Session):  # 继承
    def request(self, method, url,
                params=None, data=None, headers=None, cookies=None, files=None,
                auth=None, timeout=None, allow_redirects=True, proxies=None,
                hooks=None, stream=None, verify=None, cert=None, json=None):
        if data:
            sign = getSortParam(**data)
            data.update({'sign': sign})
        if len(params) > 2:
            sign = getSortParam(**params)
            params.update({'sign': sign})
        return super(SignSession, self).request(method, url,
                                                params=params, data=data, headers=headers, cookies=cookies, files=files,
                                                auth=auth, timeout=timeout, allow_redirects=allow_redirects,
                                                proxies=proxies,
                                                hooks=hooks, stream=stream, verify=verify, cert=cert, json=json)


class Base(object):
    def __init__(self, **kwargs):
        self._kwargs = kwargs
        self.api_version = HUPU_API_VERSION
        # 初始化设备信息
        self.sess = self._init_session()

        self._user_info = {}  # 用于存储用户信息

    def _init_session(self):
        sess = SignSession()
        headers = {
            'User-Agent': generate_user_agent(os=('android',)) + ' kanqiu/{}.13305/7214 isp/-1 network/-1'.format(
                self.api_version),
            'Content-Type': 'application/x-www-form-urlencoded',
        }
        sess.headers = headers
        sess.verify = False  # 关闭ssl验证
        return sess

    @property
    def client(self):
        if not (hasattr(self, '_client') and self._client):
            setattr(self, '_client', get_random_Imei())
        return self._client

    @property
    def android_id(self):
        if not (hasattr(self, '_android_id') and self._android_id):
            setattr(self, '_android_id', get_android_id())
        return self._android_id


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi
from __future__ import print_function
from __future__ import absolute_import

import six
import sys

PY2 = sys.version_info[0] == 2
PY3 = sys.version_info[0] == 3


def get_value(instance, path, default=None):
    dic = instance.__dict__
    for entry in path.split('.'):
        dic = dic.get(entry)
        if dic is None:
            return default
    return dic or default


# TODO 太蠢了!!!
def get_value_list(instance, path, default=None):
    # list - > 循环调用 dict方法 返回下一层
    # dict - > 直接调用 返回下一层
    # 如果 path 没了 添加
    dic = instance.__dict__
    result = []

    def get_value(_instance, _path, buffer):
        if not _instance:
            return
        if isinstance(_instance, list):
            for _ins in _instance:
                get_value(_ins, _path, buffer)
        else:
            if len(_path) == 0:
                buffer.append(_instance)
            else:
                _instance = _instance.get(_path[0])
                get_value(_instance, _path[1:], buffer)

    get_value(dic, path.split('.'), result)
    return result or default


def to_text(value, encoding="utf-8"):
    if isinstance(value, six.text_type):
        # TODO 适配测试
        if not PY3:
            if isinstance(value, unicode):
                value = value.encode(encoding)
        return value
    if isinstance(value, six.binary_type):
        return value.decode(encoding)
    return six.text_type(value)


class BaseEntry(object):
    def __init__(self, entry, default=None):
        self._name = entry.split('.')[-1]
        self.entry = entry
        self.default = default

    def __set__(self, instance, value):
        instance.__dict__[self._name] = value


class IntEntry(BaseEntry):
    def __get__(self, instance, owner):
        try:
            return int(get_value(instance, self.entry, self.default))
        except TypeError:
            return


class StringEntry(BaseEntry):
    def __get__(self, instance, owner):
        v = get_value(instance, self.entry, self.default)
        if v:
            return to_text(v)
        else:
            return v


class ListEntry(BaseEntry):
    def __get__(self, instance, owner):
        try:
            return list(get_value_list(instance, self.entry, self.default))
        except TypeError:
            return


if __name__ == '__main__':
    class A(object):
        test = ListEntry('test')

        def __init__(self, message):
            self.__dict__.update(message)


    a = A({'test': [1, 2, 3, 4]})
    print(a.test)
    a.test.append(5)
    print(a.test)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/28 上午12:43
# @Author  : wudizhangzhi

# encoding: utf-8

'''
测试用websocket服务器
'''
# !/usr/bin/env python

# !/usr/bin/env python

import asyncio
import datetime
import random
import websockets
import json


def read_log(filepath):
    with open(filepath, 'r') as f:
        lines = f.readlines()
    for line in lines:
        if 'receive:' not in line:
            continue
        yield line.split('receive:')[-1].strip()


def run_server():
    reader = read_log('/Users/admin/hupu.log.1')

    async def time(websocket, path):
        while True:
            response = next(reader)
            print('response : {}'.format(response))
            await websocket.send(response)
            await asyncio.sleep(random.random() * 3)

    start_server = websockets.serve(time, '127.0.0.1', 5000)

    asyncio.get_event_loop().run_until_complete(start_server)
    asyncio.get_event_loop().run_forever()


def socket_io():
    from flask import Flask, render_template
    from flask_socketio import SocketIO, emit

    app = Flask(__name__)
    app.config['SECRET_KEY'] = 'secret!'
    socketio = SocketIO(app)

    @app.route('/')
    def index():
        return render_template('index.html')

    @socketio.on('connect', namespace='/test')
    def test_connect():
        emit('my response', {'data': 'Connected', 'count': 0})

    @socketio.on('disconnect', namespace='/test')
    def test_disconnect():
        print('Client disconnected')

    @socketio.on('my event')
    def test_message(message):
        emit('my response', {'data': 'got it!'})

    socketio.run(app, debug=True)


if __name__ == '__main__':
    run_server()
    # socket_io()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/29 上午11:53
# @Author  : wudizhangzhi
# @File    : LiveMenu.py

from __future__ import print_function

from six import integer_types
import time
import curses
from collections import defaultdict

from hupu.api import logger

log = logger.getLogger(__name__)

"""
虎扑文字直播显示

---------------------------------
title

addition_title:
     addition_item
     addition_item
     addition_item
     addition_item


body_title:

     item
     item
     item
     item
     item
     item
----------------------------------
"""
key_bind_events = defaultdict(dict)

MAIN_PAGE = 0
SUB_PAGE = 1


def bind_event(key_list, mode_list=None):
    """
    绑定按键, 模块 和 回调
    :param key_list:
    :param mode:
    :return:
    """
    if not mode_list:
        mode_list = ['default']

    def decorator(func):
        for key in key_list:
            for mode in mode_list:
                if not isinstance(key, integer_types):
                    key = ord(key)
                key_bind_events[key][mode] = func
        return func

    return decorator


class BaseMenu(object):
    key_bind_events = defaultdict(dict)

    def __init__(self, title=None, body_title=None, addition_title=None):
        self.title = title
        self.addition_title = addition_title
        self.body_title = body_title
        self.body_title_buffer = body_title  # 缓存主体标题

        self.screen = None
        self.addition_items = list()
        self.items = list()
        self.items_buffer = list()  # 缓存item
        self.mode = 'live'
        self.page_type = MAIN_PAGE  # 页面类型

        self.should_exit = False
        self.highlight = None
        self.normal = None
        self.current_option = 0

        self._set_up_screen()
        self._set_up_colors()

    def set_items(self, items):
        self.items = items

    def _set_up_screen(self):
        self.screen = curses.initscr()
        self.screen.keypad(True)
        curses.noecho()
        curses.start_color()

    def _set_up_colors(self):
        curses.start_color()
        curses.use_default_colors()
        curses.init_pair(1, curses.COLOR_GREEN, -1)
        curses.init_pair(2, curses.COLOR_CYAN, -1)
        curses.init_pair(3, curses.COLOR_RED, -1)
        curses.init_pair(4, curses.COLOR_YELLOW, -1)
        curses.init_pair(5, curses.COLOR_WHITE, curses.COLOR_RED)
        curses.init_pair(6, curses.COLOR_WHITE, curses.COLOR_BLUE)
        self.highlight = curses.A_REVERSE
        self.normal = curses.A_NORMAL

    def reset_current_option(self):
        self.current_option = 0

    def quit(self):
        y, x = self.screen.getmaxyx()
        row = (y - 1) // 2
        col = (x - len(self.endmsg)) // 2
        self.screen.clear()
        self.screen.addstr(row, col, self.endmsg, curses.color_pair(3))
        self.screen.refresh()
        time.sleep(2)

        curses.echo()
        curses.endwin()
        self.should_exit = True

    @property
    def endmsg(self):
        return '（づ￣3￣）づ╭❤～ bye~bye~'

    def draw(self):
        """
        draw screen
        """
        self.clear_screen()
        rows = 0  # 行数
        if self.title is not None:
            # self.screen.addstr(rows, 2, self.title, curses.A_STANDOUT)
            self.screen.addstr(rows, 2, self.title, curses.color_pair(5))
            rows += 2

        if self.addition_title and self.page_type == MAIN_PAGE:
            self.screen.addstr(rows, 2, self.addition_title, curses.color_pair(6))
            rows += 1
            addition_start_row = rows
            for index, item in enumerate(self.addition_items):
                self.screen.addstr(addition_start_row + index, 4, item)
                rows += 1
            rows += 1

        if self.body_title is not None:
            self.screen.addstr(rows, 2, self.body_title, curses.A_BOLD)
            rows += 2

        screen_rows, screen_cols = self.screen.getmaxyx()
        row_max = screen_rows - rows - 1
        show_end = self.current_option + 1 if self.current_option >= row_max else row_max
        show_start = show_end - row_max if show_end > row_max else 0

        arrow = ' ->  '
        for index, item in enumerate(self.items[show_start:show_end]):
            if self.current_option == index + show_start:
                text_style = self.highlight
                self.screen.addstr(rows + index, 4, arrow + str(item), text_style)
            else:
                text_style = self.normal
                self.screen.addstr(rows + index, 4, ' ' * len(arrow) + str(item), text_style)
        self.screen.refresh()

    @bind_event(['k', curses.KEY_UP])
    def move_up(self):
        if self.current_option > 0:
            self.current_option -= 1
        else:
            self.current_option = len(self.items) - 1
        self.draw()

    @bind_event(['j', curses.KEY_DOWN])
    def move_down(self):
        if self.current_option < len(self.items) - 1:
            self.current_option += 1
        else:
            self.current_option = 0
        self.draw()

    @bind_event(['q', curses.KEY_EXIT])
    def back_or_quit(self):
        if self.page_type == MAIN_PAGE:
            self.quit()
        else:
            self.backto_mainpage()

    def clear_screen(self):
        """
        清除屏幕
        """
        self.screen.clear()

    def register(self, key, mode, func):
        key_bind_events[key][mode] = func

    def backto_mainpage(self):
        self.reset_current_option()
        self.page_type = MAIN_PAGE
        self.body_title, self.body_title_buffer = self.body_title_buffer, self.body_title
        self.items, self.items_buffer = self.items_buffer, self.items
        self.draw()

    def jumpto_subpage(self, title, subitems):
        self.reset_current_option()
        self.page_type = SUB_PAGE
        self.body_title, self.body_title_buffer = title, self.body_title
        self.items, self.items_buffer = subitems, self.items
        self.draw()

    def listen(self):
        while not self.should_exit:
            x = self.screen.getch()
            func = key_bind_events[x].get(self.mode)
            if not func:
                func = key_bind_events[x].get('default')
            if func:
                self.clear_screen()
                func(self)

if __name__ == '__main__':
    base = BaseMenu('虎扑 Proudly presented by JRs.', '今日比赛:')
    base.set_items([str(i) for i in range(10)])
    base.addition_title = '帮助信息:'
    base.addition_items = [
        'j         Down           下移',
        'k         Up             上移',
        'space     Enter          进入',
        'q         Quit           退出',
    ]
    base.draw()

    base.register(ord(' '), 'default', lambda x: print(x.title))
    base.listen()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午3:58
# @Author  : wudizhangzhi
import datetime
import time

from . import logger
from .base import Base

log = logger.getLogger(__name__)


class ForumMinxin(Base):
    def getThreadsList(self, gid):
        """
        TODO 
        """
        return self.sess.get(
            url='https://bbs.mobileapi.hupu.com/1/{}/recommend/getPlaybyplay'.format(self.api_version),
            params={
                'nav': 'nba,fifa,kog,follow,fitness,stylish,lol,pubg,cba,csl,lrw,hbl,epl,liga,seri,bund,fran,chlg,uefael,worldpre,national,afccl,zxb,confederationscup,clo,cl3,po1,nl1,tr1,sc1,ru1,be1,gr1,c1,kr1,ts1,no1,se1,ukr1,pl1,dk1,isr1,bu1,a1,ro1,gb2,gb3,gb4,es2,es3,l2,l3,rl,it2,fr2,po2,nl2,bra1,ar1n,jap1,jap2,jap3,rsk1,rsk2,aus1,tha1,hgkg,sa1,uae1,qsl,uz1,irn1,mys1,inil,sin1,mya1,in1l',
                'clientId': self.client,
                'client': '26439107',
                'crt': int(time.time() * 1000),
                'night': 0,
                'lastTid': 0,
                'stamp': int(time.time()),
                'isHome': 1,
                'time_zone': 'Asia/Shanghai',
                'android_id': self.android_id,
                'additionTid': '',
                'unfollowTid': '',
            },
        )



# !/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi
# from __future__ import unicode_literals
from six import python_2_unicode_compatible

from hupu.messages.entries import StringEntry, IntEntry, ListEntry, to_text, PY3
from hupu.api import logger

log = logger.getLogger(__name__)


class BaseMessage(object):
    __type__ = 'base'

    def __init__(self, message):
        self.__dict__.update(message)

    def __repr__(self):
        return '({})'.format(self.__str__())


class LiveMessage(BaseMessage):
    """
      {
        "rowId": 0,
        "content": {
          "uid": "18492968",
          "event": "回传德章泰-默里！分球底角贝尔坦斯！！",
          "end_time": "夏天",
          "team": 0,
          "t": 1516756188
        }
      }
    """
    __type__ = 'live'
    event = StringEntry('content.event')
    uid = StringEntry('content.uid')
    end_time = StringEntry('content.end_time')
    team = IntEntry('content.team')
    t = IntEntry('content.t')

    def __str__(self):
        return '{end_time}:  {event}'.format(end_time=self.end_time, event=self.event)


# TODO
class CasinoMessage(BaseMessage):
    __type__ = 'casino'
    event = StringEntry('event')
    uid = StringEntry('uid')
    end_time = StringEntry('end_time')
    team = IntEntry('team')
    t = IntEntry('t')

    desc = StringEntry('desc')
    status = StringEntry('status.desc')
    answers = ListEntry('answer.title')


class ScoreBoard(BaseMessage):
    """
    "scoreboard": {
          "home_tid": "21",
          "home_score": "4",
          "away_tid": "10",
          "away_score": "6",
          "process": "第一节 9:35",
          "status": "2"
        },
    """
    __type__ = 'score'
    home_tid = IntEntry('home_tid')
    home_score = IntEntry('home_score')
    away_tid = IntEntry('away_tid')
    away_score = IntEntry('away_score')
    process = StringEntry('process')  # 时间
    status = IntEntry('status')

    def __str__(self):
        return '{away_score}:{home_score} {process}'.format(away_score=self.away_score,
                                                            home_score=self.home_score,
                                                            process=self.process)


class Game(BaseMessage):
    __type__ = 'game'
    home_name = StringEntry('home_name')
    away_name = StringEntry('away_name')
    home_score = IntEntry('home_score')
    away_score = IntEntry('away_score')
    process = StringEntry('process')
    gid = IntEntry('gid')

    def __str__(self):
        return "{away_name}  {away_score} vs {home_score}  {home_name}  {process}".format(
            away_name=self.away_name,
            home_name=self.home_name,
            away_score=self.away_score,
            home_score=self.home_score,
            process=self.process,
        )

    def __repr__(self):
        return "Game({} {})".format(self.__str__(), self.gid)


class SocketMessage(BaseMessage):
    __type__ = 'socket'
    room = StringEntry('room')
    gid = StringEntry('gid')  # 比赛的id
    status = StringEntry('status')
    pid = StringEntry('pid')  # TODO 好像是交流的id

    room_live_type = IntEntry('room_live_type')

    livemessges = []

    games = []

    # casinomessages = ListEntry('casinomessages')

    def __init__(self, message):
        self.room = message.pop('room', None)
        result = message.pop('result', {})
        if self.room == 'NBA_HOME':
            if isinstance(result, list):
                for r in result:
                    self.games.append(Game(r))
        else:
            # 计分板
            scoreboard = result.pop('scoreboard', {})
            self.scoreboard = ScoreBoard(scoreboard)
            # 直播消息
            data = result.pop('data', {})
            if data:
                _livemessge = data[0]['a']
                for _lm in _livemessge:
                    self.livemessges.append(LiveMessage(_lm))

        # TODO 竞猜消息

        super(SocketMessage, self).__init__(message)


# @python_2_unicode_compatible
class News(BaseMessage):
    """
    虎扑新闻
    """
    __type__ = 'news'
    news_type_list = [1, 5]

    nid = IntEntry('nid')
    title = StringEntry('title')
    summary = StringEntry('summary')
    uptime = IntEntry('uptime')
    type = IntEntry('type')  # 1:比赛新闻? 3:帖子?  5:主题帖?
    lights = IntEntry('lights')
    replies = IntEntry('replies')
    read = IntEntry('read')

    def __str__(self):
        return '{}'.format(self.title)

    @property
    def statistics_text(self):
        return '阅读: {read} 点亮: {lights} 回复: {replies}'.format(
            read=self.read,
            lights=self.lights,
            replies=self.replies,
        )


# @python_2_unicode_compatible
class NewsDetail(BaseMessage):
    """
    虎扑新闻正文
    """
    __type__ = 'newsdetail'

    url = StringEntry('url')
    title = StringEntry('title')

    content = StringEntry('offline_data.data.news.content')

    def __str__(self):
        return self.content


class TeamRank(BaseMessage):
    """
    排行
    """
    __type__ = 'teamrank'
    rank_type = StringEntry('rank_type')
    name = StringEntry('name')
    title = StringEntry('title')
    field = StringEntry('field')

    data = ListEntry('data')

    def __str__(self):
        return '{title} {name}'.format(
            title=self.title,
            name=self.name
        )

    @property
    def to_table(self):
        """
        排行  胜-负  胜率/胜场差  近况
        """
        table = []
        table.append(self.table_title)
        if self.rank_type in ['east', 'west']:
            for i, _data in enumerate(self.data):
                table.append('{rank}.{name:<10}{win:>3}-{lost:<8}{gb:>10}{strik:>6}'.format(
                    rank=i + 1,
                    name=to_text(_data.get('name')),
                    win=to_text(_data.get('win')),
                    lost=to_text(_data.get('lost')),
                    gb=to_text(_data.get('gb')),
                    strik=to_text(_data.get('strk')),
                ))
        else:
            for _data in self.data:
                table.append('{rank}.{team_name:<20}{value}'.format(
                    rank=to_text(_data.get('rank')),
                    team_name=to_text(_data.get('team_name')),
                    value=to_text(_data.get(self.field)),
                ))
        return table

    @property
    def table_title(self):
        if self.rank_type in ['east', 'west']:
            return '排行         胜-负      胜率/胜场差     近况'
        else:
            return '{name:<20}数据'.format(name=self.name)


class PlayData(BaseMessage):
    __type__ = 'playerdata'

    name = StringEntry('name')

    data = ListEntry('data')

    def __str__(self):
        return '{}'.format(self.name)

    @property
    def to_table(self):
        table = []
        for _data in self.data:
            if 'injury_detail_cn' in _data:
                table.append('{team_name}-{player_name} {injury_part_cn} {injury_detail_cn}'.format(
                    injury_part_cn=to_text(_data.get('injury_part_cn', '')),
                    player_name=to_text(_data.get('player_name')),
                    team_name=to_text(_data.get('team_name')),
                    injury_detail_cn=to_text(_data.get('injury_detail_cn')),
                ))
            else:
                table.append('{rank}.{player_name}({team_name}){val:>20}'.format(
                    rank=to_text(_data.get('rank', '')),
                    player_name=to_text(_data.get('player_name')),
                    team_name=to_text(_data.get('team_name')),
                    val=to_text(_data.get('val')),
                ))
        return table

    @property
    def title(self):
        return '球员数据--{}'.format(self.name)


def test_message():
    sb = ScoreBoard({'home_tid': 123})
    print(sb.home_tid)
    print(type(sb))


if __name__ == '__main__':
    test_message()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/29 下午8:17
# @Author  : wudizhangzhi
import time
import curses

import sys

import os

from hupu.menus.BaseMenu import BaseMenu, SUB_PAGE, bind_event
from hupu.api import logger
from hupu.messages.entries import to_text, PY3
from hupu.utils import purge_text, text_to_list
from hupu.hupulivewebsocket import HupuSocket

log = logger.getLogger(__name__)

HELPER_LINES = [
    'j         Down           下移',
    'k         Up             上移',
    'space     Enter          进入',
    'q         Quit           退出',
    'Ctrl-C           退出文字直播',
]


class HupuMenu(BaseMenu):
    def __init__(self, hupuapp, title=None, body_title=None, addition_title=None):
        super(HupuMenu, self).__init__(title, body_title, addition_title)
        self.hupuapp = hupuapp

        self.title = '虎扑 Proudly presented by JRs.'
        self.body_title = '今日比赛:'
        self.addition_title = '帮助信息:'
        self.addition_items = HELPER_LINES

    @bind_event([' ', curses.KEY_ENTER], ['teamranks', 'playerdata'])
    def choose_datadetail(self):
        """
        跳转到具体数据
        """
        if not self.page_type == SUB_PAGE:
            teamrank = self.items[self.current_option]
            self.jumpto_subpage(teamrank.title, teamrank.to_table)
        else:
            self.draw()

    @bind_event([' ', curses.KEY_ENTER], ['news'])
    def choose_news(self):
        if not self.page_type == SUB_PAGE:
            news = self.items[self.current_option]
            newsdetail = self.hupuapp.getNewsDetailSchema(news.nid)
            # 正文
            content = purge_text(newsdetail.content)
            # 中文显示问题
            self.jumpto_subpage(newsdetail.title, text_to_list(content, self.screen.getmaxyx()[0]))
        else:
            self.draw()

    @bind_event([' ', curses.KEY_ENTER], ['live'])
    def choose_live(self):
        self.clear_screen()
        self.screen.refresh()
        game_selected = self.items[self.current_option]
        host, port = self.hupuapp.getIpAdress()
        # debug
        if not PY3:  # python2 unicode comaptible
            sys.stdout = os.fdopen(sys.stdout.fileno(), 'w', 0)
        hs = HupuSocket(game=game_selected, client=self.hupuapp.client, host=host, port=port)
        # try:
        hs.run()
        # except KeyboardInterrupt:
        log.debug('文字直播停止')
        # print('文字直播停止\n\r')
        time.sleep(1)
        self.draw()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午3:53
# @Author  : wudizhangzhi
import json
import time

from hupu.api import logger
from hupu.api.base import Base
from hashlib import md5

log = logger.getLogger(__name__)


class LoginMixin(Base):
    def _login(self):
        username = self._kwargs.get('USERNAME', None)
        password = self._kwargs.get('PASSWORD', None)
        assert (username and password)
        url_login = 'https://games.mobileapi.hupu.com/1/{version}/user/loginUsernameEmail'.format(
            version=self.api_version)
        password_md5 = md5(password.encode('utf8')).hexdigest()
        # TODO 需要机械生成, 看上去调用两次可以登录
        # client = get_random_Imei()
        # client = '356359011002417'

        # client = '862561035110764'
        # client = '35672408061946'

        params = {
            'client': self.client
        }
        data = {
            'password': password_md5,
            'crt': str(int(time.time() * 1000)),
            'night': '0',
            'channel': 'oppo',
            'client': self.client,
            'time_zone': 'Asia/Shanghai',
            'android_id': self.android_id,
            'username': username,
        }
        log.debug('登录post信息: {}'.format(json.dumps(data, indent=4)))
        r = self.sess.post(url_login, params=params, data=data, timeout=10)
        r_json = r.json()
        log.debug('登录返回信息: {}'.format(r_json))
        login_success = self._is_login_success(r_json)
        if login_success:
            # 存储用户信息
            self._user_info = r_json['result']

    @staticmethod
    def _is_login_success(response_json):
        if 'error' in response_json:
            raise Exception('登录失败,返回: {}'.format(response_json['error']['text']))
        elif response_json['is_login'] == 1:
            print('登录成功')
            log.debug('登录成功')
            return True
        else:
            return False


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午3:53
# @Author  : wudizhangzhi

import sys

sys.path.append('../..')
import time

from hupu.api import logger
from hupu.api.base import Base
from hupu.messages.messages import News, NewsDetail

log = logger.getLogger(__name__)


class NewsMixin(Base):
    def _getNews(self):
        """
        获取新闻
        """
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/nba/getNews'.format(self.api_version),
            params={
                'crt': int(time.time() * 1000),
                'night': 0,
                'channel': 'myapp',
                'client': self.client,
                'time_zone': 'Asia/Shanghai',
                'android_id': self.android_id,
                'entrance': '-1',
            }
        )

    def getNews(self):
        r = self._getNews().json()
        log.debug('获取新闻: {}'.format(r))
        return [News(news) for news in r['result']['data'] if news.get('type') in News.news_type_list]

    def _getNewsDetailSchema(self, nid):
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/nba/getNewsDetailSchema'.format(self.api_version),
            params={
                'crt': int(time.time() * 1000),
                'night': 0,
                'channel': 'myapp',
                'nid': nid,
                'nopic': 0,
                'catetype': 'news',
                'token': '',
                'top_ncid': -1,
                'replies': '',
                'client': self.client,
                'time_zone': 'Asia/Shanghai',
                'android_id': self.android_id,
                'entrance': '-1',
            }
        )

    def getNewsDetailSchema(self, nid):
        j = self._getNewsDetailSchema(nid).json()
        log.debug(j)
        return NewsDetail(j['result'])

    def _getRecap7(self, gid):
        '''
        获取赛后
        :param gid: 
        :return: html
        '''
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/nba/getRecap7'.format(self.api_version),
            params={
                'client': self.client,
                'gid': gid,
                'nopic': 0,
                'night': 0,
                'entrance': '-1',
            }
        )


if __name__ == '__main__':
    n = NewsMixin()
    # print(n.getNewsDetailSchema(2255215))
    print(n._getRecap7(153764).text)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author: wudizhangzhi
# @Date:   2018-08-24 21:51:57

import logging
import os
from logging.handlers import RotatingFileHandler

LOG_PATH = os.path.join(os.path.expanduser('~'), 'hupu.log')


def getLogger(name):
    log = logging.getLogger(name)
    log.setLevel(logging.DEBUG)

    # file output hanlder
    fh = RotatingFileHandler(LOG_PATH,
                             maxBytes=5 * 1024 * 1024 * 10,
                             backupCount=1)
    fh.setLevel(logging.DEBUG)

    fh.setFormatter(logging.Formatter(
        '%(asctime)s - %(levelname)s - %(name)s:%(lineno)s: %(message)s'))
    log.addHandler(fh)

    return log



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi


import hupu
from setuptools import setup, find_packages

install_requires = open("requirements.txt").readlines()

setup(
    name='HupuApp',
    packages=find_packages(exclude=('test',)),
    package_data={'hupu': ['tac.csv']},
    version=hupu.__version__,
    author=hupu.__author__,
    author_email='554330595@qq.com',
    url="https://github.com/wudizhangzhi/HupuApp",
    # download_url='https://github.com/wudizhangzhi/HupuApp/archive/1.0.0.tar.gz',
    description='Proudly presented by Hupu JRs',
    license="MIT",
    # py_modules=['hupu'],
    keywords='hupu',
    entry_points={
        "console_scripts": ["HupuApp = hupu.hupuapp:start", ]
    },
    python_requires='>=2.6,',
    install_requires=install_requires,
    include_package_data=True,
    data_files=[
        ('HupuApp', ['requirements.txt', ]),
    ],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午4:16
# @Author  : wudizhangzhi

import sys
import locale
from logging.handlers import RotatingFileHandler

import os

locale.setlocale(locale.LC_ALL, '')
import time

sys.path.append('..')


def test_news_detail():
    from news import NewsMixin
    n = NewsMixin()
    print(n.getNewsDetailSchema(2255215))


from hupu.hupuapp import HupuApp


def test_unicode():
    hupu = HupuApp()
    games = hupu.getGames()
    print(games)

    import curses
    win = curses.initscr()
    win.clear()
    win.addstr(0, 0, str('   我们在一起'))
    win.refresh()
    time.sleep(1)
    curses.endwin()


def test_logger():
    import logging
    log = logging.getLogger('websocket')
    fh = RotatingFileHandler('log.log')
    fh.setLevel(logging.DEBUG)

    fh.setFormatter(logging.Formatter(
        '%(asctime)s - %(levelname)s - %(name)s:%(lineno)s: %(message)s'))
    log.addHandler(fh)
    # logger.setLevel(logging.CRITICAL)
    # logger.setLevel(logging.CRITICAL)
    # logger.setLevel(logging.CRITICAL)
    # logger.setLevel(logging.CRITICAL)
    import websocket
    from websocket import _logging

    _logging.error('hello')


def test_scoket_print():
    # from hupu.hupulivewebsocket import test
    # test()
    from hupu.messages.messages import Game
    # import sys
    import curses
    #
    def incurses(stdscr):
        stdscr.addstr(0, 0, "Exiting in ")
        stdscr.addstr(2, 0, "Hello World from Curses!")
        for i in range(5, -1, -1):
            stdscr.addstr(0, 11, str(i))
            stdscr.refresh()
            time.sleep(1)
        curses.endwin()

    curses.wrapper(incurses)
    # sys.stdout = os.fdopen(sys.stdout.fileno(), 'w', 0)
    sys.stdout = sys.__stdout__
    sys.stderr = sys.__stderr__
    print("After curses")
    # # curses.echo()
    # # curses.reset_shell_mode()
    # # print(sys.stdout)
    # game = Game({'gid': 153735, 'home_name': '勇士', 'away_name': '骑士'})
    # hlws = HupuSocket(game=game, client='008796750504411', host='127.0.0.1', port=5000)
    # hlws.run()
    # #
    # # def get_token():
    # #     return ''
    # #
    # # hlws.get_token = get_token
    # # hlws.run()
    i = 0
    while i < 100:
        print('this is a test. {}'.format(i))
        # sys.stdout.write('this is a test. {}'.format(i))
        i += 1
        time.sleep(1)


def test_init():
    hupuapp = HupuApp()
    print(hupuapp.getInit().json())


if __name__ == '__main__':
    # test_news_detail()
    # test_unicode()
    # test_logger()
    test_scoket_print()
    # test_init()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 上午3:53
# @Author  : wudizhangzhi
import json
import sys

sys.path.append('../..')
import time

from hupu.api import logger
from hupu.api.base import Base
from hupu.messages.messages import TeamRank, PlayData

log = logger.getLogger(__name__)


class DatasMixin(Base):
    def _getData(self):
        """
        获取球队数据排行
        """
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/data/nba'.format(self.api_version),
            params={
                'client': self.client,
                'offline': 'json',
                'webp': 1,
            }
        ).json()

    def getDatas(self):
        r_json = self._getData()
        log.debug(json.dumps(r_json, indent=2))
        return [TeamRank(i) for i in r_json['data']['data']]

    def _getPlayerDataInGenernal(self, datatype='regular'):
        """
        球员数据接口
        :param datatype: regular, injury, daily
        """
        return self.sess.get(
            url='https://games.mobileapi.hupu.com/1/{}/nba/getPlayerDataInGeneral/'.format(self.api_version),
            params={
                'client': self.client,
                'offline': 'json',
                'type': datatype,
                'webp': 1,
            }
        ).json()

    def getPlayerDataInGenernal(self, datatype='regular'):
        r_json = self._getPlayerDataInGenernal(datatype)
        log.debug(log.debug(json.dumps(r_json, indent=2)))
        return [PlayData(i) for i in r_json['data']]


if __name__ == '__main__':
    d = DatasMixin()
    print(d.getDatas())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi
from hupu.version import version

__version__ = version
__author__ = 'wudizhangzhi'
# __all__ = ['HupuApp']
